@@ -1,21 +1,8 @@
 /*
- *   Copyright 2006-2007 Aaron Seigo <aseigo@kde.org>
- *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library General Public License as
- *   published by the Free Software Foundation; either version 2, or
- *   (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details
- *
- *   You should have received a copy of the GNU Library General Public
- *   License along with this program; if not, write to the
- *   Free Software Foundation, Inc.,
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2006-2007 Aaron Seigo <aseigo@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "abstractrunner.h"
 #include "abstractrunner_p.h"
@@ -26,14 +13,13 @@
 #include <QMimeData>
 #include <QMutex>
 
-#include "krunner_debug.h"
-#include <kplugininfo.h>
-#include <ksharedconfig.h>
-#include <kservicetypetrader.h>
-#include <klocalizedstring.h>
-#include <Plasma/PluginLoader>
-#include <qstandardpaths.h>
+#include <KSharedConfig>
+#include <KLocalizedString>
+#if KRUNNER_BUILD_DEPRECATED_SINCE(5, 65)
+#include <Plasma/Package>
+#endif
 
+#include "krunner_debug.h"
 #include "querymatch.h"
 #include "runnercontext.h"
 
@@ -47,22 +33,47 @@ AbstractRunner::AbstractRunner(QObject *parent, const QString &path)
     d->init(path);
 }
 
+AbstractRunner::AbstractRunner(const KPluginMetaData &pluginMetaData, QObject *parent)
+    : QObject(parent),
+      d(new AbstractRunnerPrivate(this))
+{
+    d->init(pluginMetaData);
+}
+
+#if KRUNNER_BUILD_DEPRECATED_SINCE(5, 72) && KSERVICE_BUILD_DEPRECATED_SINCE(5, 0)
 AbstractRunner::AbstractRunner(const KService::Ptr service, QObject *parent)
     : QObject(parent),
       d(new AbstractRunnerPrivate(this))
 {
     d->init(service);
 }
+#endif
 
 AbstractRunner::AbstractRunner(QObject *parent, const QVariantList &args)
     : QObject(parent),
       d(new AbstractRunnerPrivate(this))
 {
     if (!args.isEmpty()) {
+#if KRUNNER_BUILD_DEPRECATED_SINCE(5, 72) && KSERVICE_BUILD_DEPRECATED_SINCE(5, 0)
+        // backward-compatible support has metadata only as second argument
+        // which we prefer of course
+        if (args.size() > 1) {
+            const KPluginMetaData metaData = args[1].value<KPluginMetaData>();
+#else
+            const KPluginMetaData metaData = args[0].value<KPluginMetaData>();
+#endif
+            if (metaData.isValid()) {
+                d->init(metaData);
+                return;
+            }
+#if KRUNNER_BUILD_DEPRECATED_SINCE(5, 72) && KSERVICE_BUILD_DEPRECATED_SINCE(5, 0)
+        }
+
         KService::Ptr service = KService::serviceByStorageId(args[0].toString());
         if (service) {
             d->init(service);
         }
+#endif
     }
 }
 
@@ -78,7 +89,7 @@ KConfigGroup AbstractRunner::config() const
         group = QStringLiteral("UnnamedRunner");
     }
 
-    KConfigGroup runners(KSharedConfig::openConfig(), "Runners");
+    KConfigGroup runners(KSharedConfig::openConfig(QStringLiteral("krunnerrc")), "Runners");
     return KConfigGroup(&runners, group);
 }
 
@@ -134,9 +145,6 @@ void AbstractRunner::performMatch(Plasma::RunnerContext &localContext)
     if (!slowed && runtime > reasonableRunTime) {
         // we punish runners that return too slowly, even if they don't bring
         // back matches
-#ifndef NDEBUG
-        // qCDebug(KRUNNER) << id() << "runner is too slow, putting it on the back burner.";
-#endif
         d->fastRuns = 0;
         setSpeed(SlowSpeed);
     }
@@ -147,9 +155,6 @@ void AbstractRunner::performMatch(Plasma::RunnerContext &localContext)
         if (d->fastRuns > 2) {
             // we reward slowed runners who bring back matches fast enough
             // 3 times in a row
-#ifndef NDEBUG
-            // qCDebug(KRUNNER) << id() << "runner is faster than we thought, kicking it up a notch";
-#endif
             setSpeed(NormalSpeed);
         }
     }
@@ -206,20 +211,26 @@ QMimeData *AbstractRunner::mimeDataForMatch(const QueryMatch &match)
     return result;
 }
 
+#if KRUNNER_BUILD_DEPRECATED_SINCE(5, 71)
 bool AbstractRunner::hasRunOptions()
 {
     return d->hasRunOptions;
 }
+#endif
 
+#if KRUNNER_BUILD_DEPRECATED_SINCE(5, 71)
 void AbstractRunner::setHasRunOptions(bool hasRunOptions)
 {
     d->hasRunOptions = hasRunOptions;
 }
+#endif
 
+#if KRUNNER_BUILD_DEPRECATED_SINCE(5, 71)
 void AbstractRunner::createRunOptions(QWidget *parent)
 {
-    Q_UNUSED(parent);
+    Q_UNUSED(parent)
 }
+#endif
 
 AbstractRunner::Speed AbstractRunner::speed() const
 {
@@ -294,7 +305,7 @@ QString AbstractRunner::name() const
 QIcon AbstractRunner::icon() const
 {
     if (d->runnerDescription.isValid()) {
-        return QIcon::fromTheme(d->runnerDescription.icon());
+        return QIcon::fromTheme(d->runnerDescription.iconName());
     }
 
     return QIcon();
@@ -303,7 +314,7 @@ QIcon AbstractRunner::icon() const
 QString AbstractRunner::id() const
 {
     if (d->runnerDescription.isValid()) {
-        return d->runnerDescription.pluginName();
+        return d->runnerDescription.pluginId();
     }
 
     return objectName();
@@ -312,32 +323,46 @@ QString AbstractRunner::id() const
 QString AbstractRunner::description() const
 {
     if (d->runnerDescription.isValid()) {
-        return d->runnerDescription.property(QStringLiteral("Comment")).toString();
+        return d->runnerDescription.description();
     }
 
     return objectName();
 }
 
+#if KRUNNER_BUILD_DEPRECATED_SINCE(5, 72)
 KPluginInfo AbstractRunner::metadata() const
+{
+    return KPluginInfo::fromMetaData(d->runnerDescription);
+}
+#endif
+
+KPluginMetaData AbstractRunner::metadata(RunnerReturnPluginMetaDataConstant) const
 {
     return d->runnerDescription;
 }
 
+#if KRUNNER_BUILD_DEPRECATED_SINCE(5, 65)
 Package AbstractRunner::package() const
 {
-    return d->package ? *d->package : Package();
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_CLANG("-Wdeprecated-declarations")
+QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")
+    return Package();
+QT_WARNING_POP
 }
-
+#endif
 
 void AbstractRunner::init()
 {
     reloadConfiguration();
 }
 
+#if KRUNNER_BUILD_DEPRECATED_SINCE(5, 73)
 DataEngine *AbstractRunner::dataEngine(const QString &name) const
 {
     return d->dataEngine(name);
 }
+#endif
 
 bool AbstractRunner::isMatchingSuspended() const
 {
@@ -360,7 +385,6 @@ AbstractRunnerPrivate::AbstractRunnerPrivate(AbstractRunner *r)
       blackListed(RunnerContext::None),
       runner(r),
       fastRuns(0),
-      package(nullptr),
       defaultSyntax(nullptr),
       hasRunOptions(false),
       suspendMatching(false)
@@ -369,19 +393,28 @@ AbstractRunnerPrivate::AbstractRunnerPrivate(AbstractRunner *r)
 
 AbstractRunnerPrivate::~AbstractRunnerPrivate()
 {
-    delete package;
-    package = nullptr;
 }
 
+void AbstractRunnerPrivate::init(const KPluginMetaData &pluginMetaData)
+{
+    runnerDescription = pluginMetaData;
+}
+
+#if KRUNNER_BUILD_DEPRECATED_SINCE(5, 72) && KSERVICE_BUILD_DEPRECATED_SINCE(5, 0)
 void AbstractRunnerPrivate::init(const KService::Ptr service)
 {
-    runnerDescription = KPluginInfo(service);
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_CLANG("-Wdeprecated-declarations")
+QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")
+    const KPluginInfo pluginInfo(service);
+    runnerDescription = pluginInfo.isValid() ? pluginInfo.toMetaData() : KPluginMetaData();
+QT_WARNING_POP
 }
+#endif
 
 void AbstractRunnerPrivate::init(const QString &path)
 {
-    runnerDescription = KPluginInfo(path + QStringLiteral("/metadata.desktop"));
-    const QString api = runnerDescription.property(QStringLiteral("X-Plasma-API")).toString();
+    runnerDescription = KPluginMetaData(path + QStringLiteral("/metadata.desktop"));
 }
 
 } // Plasma namespace
