@@ -1,21 +1,8 @@
 /*
- *   Copyright 2006-2009 Aaron Seigo <aseigo@kde.org>
- *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library General Public License as
- *   published by the Free Software Foundation; either version 2, or
- *   (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details
- *
- *   You should have received a copy of the GNU Library General Public
- *   License along with this program; if not, write to the
- *   Free Software Foundation, Inc.,
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2006-2009 Aaron Seigo <aseigo@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #ifndef ABSTRACTRUNNER_P_H
 #define ABSTRACTRUNNER_P_H
@@ -24,14 +11,19 @@
 
 #include <KPluginMetaData>
 
-#include "plasma/dataengineconsumer.h"
+#if KRUNNER_BUILD_DEPRECATED_SINCE(5, 73)
+#include <Plasma/DataEngineConsumer>
+#endif
 
 namespace Plasma
 {
 
 class AbstractRunner;
 
-class AbstractRunnerPrivate : public DataEngineConsumer
+class AbstractRunnerPrivate
+#if KRUNNER_BUILD_DEPRECATED_SINCE(5, 73)
+    : public DataEngineConsumer
+#endif
 {
 public:
     AbstractRunnerPrivate(AbstractRunner *r);
