@@ -1,28 +1,15 @@
 /*
- *   Copyright (C) 2007, 2009 Ryan P. Bitanga <ryan.bitanga@gmail.com>
- *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library General Public License as
- *   published by the Free Software Foundation; either version 2, or
- *   (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details
- *
- *   You should have received a copy of the GNU Library General Public
- *   License along with this program; if not, write to the
- *   Free Software Foundation, Inc.,
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2007, 2009 Ryan P. Bitanga <ryan.bitanga@gmail.com>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "runnerjobs_p.h"
 
 #include <QTimer>
 #include <QMutexLocker>
-#include "krunner_debug.h"
 
+#include "krunner_debug.h"
 #include "runnermanager.h"
 #include "querymatch.h"
 
@@ -49,7 +36,6 @@ bool DelayedRunnerPolicy::canRun(ThreadWeaver::JobPointer job)
     QSharedPointer<FindMatchesJob> aJob(job.dynamicCast<FindMatchesJob>());
     if (QTimer *t = aJob->delayTimer()) {
         // If the timer is active, the required delay has not been reached
-        //qCDebug(KRUNNER) << "delayed timer" << aJob->runner()->name() << !t->isActive();
         return !t->isActive(); // DATA RACE!  (with QTimer start/stop from runnermanager.cpp)
     }
 
@@ -125,8 +111,7 @@ FindMatchesJob::FindMatchesJob(Plasma::AbstractRunner *runner,
     : ThreadWeaver::Job(),
       m_context(*context, nullptr),
       m_runner(runner),
-      m_timer(nullptr),
-      m_decorator(new ThreadWeaver::QObjectDecorator(this, true))
+      m_timer(nullptr)
 {
     QMutexLocker l(mutex()); Q_UNUSED(l);
     if (runner->speed() == Plasma::AbstractRunner::SlowSpeed) {
@@ -150,13 +135,12 @@ void FindMatchesJob::setDelayTimer(QTimer *timer)
     m_timer = timer;
 }
 
-void FindMatchesJob::run(ThreadWeaver::JobPointer, ThreadWeaver::Thread*)
+void FindMatchesJob::run(ThreadWeaver::JobPointer self, ThreadWeaver::Thread*)
 {
-//     qCDebug(KRUNNER) << "Running match for " << m_runner->objectName()
-//              << " in Thread " << thread()->id() << endl;
     if (m_context.isValid()) {
         m_runner->performMatch(m_context);
     }
+    emit done(self);
 }
 
 int FindMatchesJob::priority() const
@@ -178,7 +162,7 @@ DelayedJobCleaner::DelayedJobCleaner(const QSet<QSharedPointer<FindMatchesJob> >
     connect(m_weaver, SIGNAL(finished()), this, SLOT(checkIfFinished()));
 
     for (auto it = m_jobs.constBegin(); it != m_jobs.constEnd(); ++it) {
-        connect((*it)->decorator(), &ThreadWeaver::QObjectDecorator::done, this, &DelayedJobCleaner::jobDone);
+        connect(it->data(), &FindMatchesJob::done, this, &DelayedJobCleaner::jobDone);
     }
 }
 
